﻿import es
import keyvalues
import langlib
import os
import playerlib
import popuplib

kg_admins = "soccer_mod_admins"
kg_set = "sm_keygroup_set"
lang_dir = "cstrike/addons/eventscripts/soccer_mod_2010/language/"
popup_name = "sm_popup_admin_manager_admins"

common = langlib.Strings(lang_dir + "popup_common.ini")
messages = langlib.Strings(lang_dir + "admin/manager/messages_manager_admins.ini")
messages_common = langlib.Strings(lang_dir + "messages_common.ini")

access = ["match", "cap", "referee", "training", "skins", "change_map", "settings", "manager"]

# ******************** Load ********************
def load():
	if os.path.isfile("cstrike/cfg/soccer_mod/es_soccer_mod_admins_db.txt") == True:
		es.keygroupload("soccer_mod_admins", "soccer_mod")

	create_popup()

	es.addons.registerSayFilter(filter)

	es.load("soccer_mod_2010/admin/manager/admins/create")

# ******************** Create popup ********************
def create_popup():
	text = langlib.Strings(lang_dir + "admin/manager/popup_admin_manager_admins.ini")

	popup = popuplib.create(popup_name)

	popup.addline("SOCCER MOD %s" % (text("title")))
	popup.addline(" ")
	popup.addline("->1. %s" % (text("add")))
	popup.addline("->2. %s" % (text("add_player")))
	popup.addline("->3. %s" % (text("edit")))
	popup.addline("->4. %s" % (text("remove")))
	popup.addline(" ")
	popup.addline("->9. %s" % (common("back")))
	popup.addline(" ")
	popup.addline("0. %s" % (common("close")))

	popup.select(1, select_add)
	popup.select(2, select_add_player)
	popup.select(3, select_edit)
	popup.select(4, select_remove_admin)

	for i in range(5, 9):
		popup.submenu(i, popup_name)

	popup.submenu(9, "sm_popup_admin_manager")

def create_popup_edit(userid, steamid):
	name = "sm_popup_%s" % (userid)
	if popuplib.exists(name):
		popuplib.delete(name)

	text = langlib.Strings(lang_dir + "admin/manager/popup_admin_manager_admins_edit.ini")

	popup = popuplib.create(name)

	popup.addline("SOCCER MOD %s" % (text("title")))
	popup.addline(" ")
	popup.addline("->1. %s: %s" % (text("name"), es.keygetvalue(kg_admins, steamid, "name")))
	popup.addline("->2. %s: %s" % (text("steamid"), steamid))
	popup.addline("->3. %s" % (text("access")))
	popup.addline(" ")
	popup.addline("->9. %s" % (common("back")))
	popup.addline(" ")
	popup.addline("0. %s" % (common("close")))

	popup.select(1, select_edit_name)
	popup.select(2, select_edit_steamid)
	popup.select(3, select_edit_access)

	for i in range(4, 9):
		popup.submenu(i, name)

	popup.submenu(9, popup_name)

	popuplib.send(name, userid)

def create_popup_edit_access(userid, steamid):
	name = "sm_popup_%s" % (userid)
	if popuplib.exists(name):
		popuplib.delete(name)

	text = langlib.Strings(lang_dir + "admin/manager/popup_admin_manager_admins_edit_access.ini")

	popup = popuplib.create(name)

	popup.addline("SOCCER MOD %s" % (text("title")))
	popup.addline(" ")
	popup.addline("%s:" % (es.keygetvalue(kg_admins, steamid, "name")))
	popup.addline(" ")

	for i in range(0, len(access)):
		try:
			if int(es.keygetvalue(kg_admins, steamid, access[i])) == 1:
				line = "->%s. %s: %s" % (i + 1, text(access[i]), text("yes"))
			else:
				line = "->%s. %s: %s" % (i + 1, text(access[i]), text("no"))
		except ValueError:
			line = "->%s. %s: %s" % (i + 1, text(access[i]), text("no"))
		popup.addline(line)

	popup.addline(" ")
	popup.addline("->9. %s" % (common("back")))
	popup.addline(" ")
	popup.addline("0. %s" % (common("close")))

	for i in range(1, len(access) + 1):
		popup.select(i, edit_access)

	popup.select(9, select_edit_access_back)

	popuplib.send(name, userid)

# ******************** Events ********************
def filter(userid, text, teamonly):
	steamid = es.getplayersteamid(userid)
	if es.exists("key", kg_set, steamid) == 1:
		text = text.strip('"')
		type = es.keygetvalue(kg_set, steamid, "setting_type")
		if type == "manager_admin_add_name":
			add_name(text, userid, steamid)
			return (0, None, 0)
		elif type == "manager_admin_add_steamid":
			add_steamid(text, userid, steamid)
			return (0, None, 0)
		elif type == "manager_admin_edit_name":
			edit_name(text, userid, steamid)
			return (0, None, 0)
		elif type == "manager_admin_edit_steamid":
			edit_steamid(text, userid, steamid)
			return (0, None, 0)
		else:
			return (userid, text, teamonly)
	else:
		return (userid, text, teamonly)

# ******************** Popup choice ********************
def select_add(userid, choice, popupid):
	set_key(userid, "manager_admin_add_name", "add_admin_name")

def select_add_player(userid, choice, popupid):
	name = "sm_popup_%s" % (userid)
	if popuplib.exists(name):
		popuplib.delete(name)

	myPopup = popuplib.easymenu(name, None, add)
	myPopup.settitle(messages("select_player"))

	for player in playerlib.getPlayerList("#human"):
		myPopup.addoption(player.userid, player.name)

	myPopup.submenu(10, popup_name)

	popuplib.send(name, userid)

def select_edit(userid, choice, popupid):
	name = "sm_popup_%s" % (userid)
	if popuplib.exists(name):
		popuplib.delete(name)

	myPopup = popuplib.easymenu(name, None, edit)
	myPopup.settitle(messages("edit_admin"))

	admins = keyvalues.getKeyGroup("soccer_mod_admins")
	for item in admins:
		myPopup.addoption(item, es.keygetvalue("soccer_mod_admins", item, "name"))

	myPopup.submenu(10, "sm_popup_admin_manager_admins")

	popuplib.send(name, userid)

def select_edit_name(userid, choice, popupid):
	set_key(userid, "manager_admin_edit_name", "add_admin_name")

def select_edit_steamid(userid, choice, popupid):
	set_key(userid, "manager_admin_edit_steamid", "add_admin_steamid")

def select_edit_access(userid, choice, popupid):
	create_popup_edit_access(userid, es.keygetvalue(kg_set, es.getplayersteamid(userid), "edit"))

def select_edit_access_back(userid, choice, popupid):
	create_popup_edit(userid, es.keygetvalue(kg_set, es.getplayersteamid(userid), "edit"))

def select_remove_admin(userid, choice, popupid):
	name = "sm_popup_%s" % (userid)
	if popuplib.exists(name):
		popuplib.delete(name)

	myPopup = popuplib.easymenu(name, None, remove)
	myPopup.settitle(messages("edit_admin"))

	admins = keyvalues.getKeyGroup("soccer_mod_admins")
	for item in admins:
		myPopup.addoption(item, es.keygetvalue("soccer_mod_admins", item, "name"))

	myPopup.submenu(10, "sm_popup_admin_manager_admins")

	popuplib.send(name, userid)

# ******************** Easymenu choice ********************
def add(userid, choice, keymenuname):
	tokens = {}
	player = playerlib.getPlayer(userid)

	name = "sm_popup_%s" % (userid)
	if popuplib.exists(name):
		popuplib.delete(name)

	if es.exists("userid", choice) == 1:
		target = playerlib.getPlayer(choice)
		tokens["name"] = target.name

		if es.exists("key", kg_admins, target.steamid) == 0:
			es.keycreate(kg_admins, target.steamid)
			es.keysetvalue(kg_admins, target.steamid, "name", target.name)

			for item in access:
				es.keysetvalue(kg_admins, target.steamid, item, 0)

			es.server.cmd("keygroupsort %s name asc #alpha" % (kg_admins))
			es.keygroupsave(kg_admins, "soccer_mod")

			es.tell(userid, "#green", messages("admin_added", tokens, player.get("lang")))

			es.keycreate(kg_set, player.steamid)
			es.keysetvalue(kg_set, player.steamid, "edit", target.steamid)

			create_popup_edit_access(userid, target.steamid)
		else:
			es.tell(userid, "#green", messages("add_admin_exist", tokens, player.get("lang")))
			popuplib.send(popup_name, userid)
	else:
		es.tell(userid, "#green", messages_common("no_player_found", tokens, player.get("lang")))
		popuplib.send(popup_name, userid)

def edit(userid, choice, keymenuname):
	if es.exists("key", kg_admins, choice) == 1:
		steamid = es.getplayersteamid(userid)

		if es.exists("key", kg_set, steamid) == 0:
			es.keycreate(kg_set, steamid)

		es.keysetvalue(kg_set, steamid, "edit", choice)

		create_popup_edit(userid, choice)
	else:
		tokens = {}
		tokens["name"] = choice

		player = playerlib.getPlayer(userid)

		es.tell(userid, "#green", messages("admin_no_exist", tokens, player.get("lang")))

		popuplib.send(popup_name, userid)

def remove(userid, choice, keymenuname):
	tokens = {}
	player = playerlib.getPlayer(userid)

	number = 0
	for admin in keyvalues.getKeyGroup(kg_admins):
		value = str(admin)
		value = value.encode("utf-8")
		if value != str(choice).encode("utf-8"):
			if int(admin["manager"]) == 1:
				number += 1

	if number > 0:
		if es.exists("key", kg_admins, choice) == 1:
			tokens["name"] = es.keygetvalue(kg_admins, choice, "name")

			es.keydelete(kg_admins, choice)
			es.keygroupsave(kg_admins, "soccer_mod")

			es.tell(userid, "#green", messages("admin_removed", tokens, player.get("lang")))
		else:
			tokens["name"] = choice

			es.tell(userid, "#green", messages("admin_no_exist", tokens, player.get("lang")))
	else:
		es.tell(userid, "#green", messages("1_admin", tokens, player.get("lang")))

	popuplib.send(popup_name, userid)

# ******************** Functions ********************
def add_name(text, userid, steamid):
	if text != "!cancel":
		es.keysetvalue(kg_set, steamid, "setting_type", "manager_admin_add_steamid")
		es.keysetvalue(kg_set, steamid, "name", text)

		tokens = {}

		player = playerlib.getPlayer(userid)

		es.tell(userid, "#green", messages("add_admin_steamid", tokens, player.get("lang")))
	else:
		clear_key(userid, steamid)

def add_steamid(text, userid, steamid):
	if text != "!cancel":
		name = es.keygetvalue(kg_set, steamid, "name")

		tokens = {}
		tokens["name"] = name
		player = playerlib.getPlayer(userid)

		if es.exists("key", kg_admins, text) == 0:
			es.keycreate(kg_admins, text)
			es.keysetvalue(kg_admins, text, "name", name)

			for item in access:
				es.keysetvalue(kg_admins, text, item, 0)

			es.server.cmd("keygroupsort %s name asc #alpha" % (kg_admins))
			es.keygroupsave(kg_admins, "soccer_mod")

			es.tell(userid, "#green", messages("admin_added", tokens, player.get("lang")))

			es.keydelete(kg_set, steamid)
			es.keycreate(kg_set, steamid)
			es.keysetvalue(kg_set, steamid, "edit", text)

			create_popup_edit_access(userid, text)
		else:
			es.tell(userid, "#green", messages("add_admin_exist", tokens, player.get("lang")))
			clear_key(userid, steamid)
	else:
		clear_key(userid, steamid)

def edit_name(text, userid, steamid):
	user_steamid = es.getplayersteamid(userid)
	steamid = es.keygetvalue(kg_set, user_steamid, "edit")

	if text != "!cancel":
		es.keysetvalue(kg_admins, steamid, "name", text)

		es.server.cmd("keygroupsort %s name asc #alpha" % (kg_admins))
		es.keygroupsave(kg_admins, "soccer_mod")

		tokens = {}
		tokens["name"] = text
		player = playerlib.getPlayer(userid)
		es.tell(userid, "#green", messages("name_changed", tokens, player.get("lang")))

	es.keydelete(kg_set, user_steamid)
	es.keycreate(kg_set, user_steamid)
	es.keysetvalue(kg_set, user_steamid, "edit", steamid)

	create_popup_edit(userid, steamid)

def edit_steamid(text, userid, steamid):
	user_steamid = es.getplayersteamid(userid)
	steamid = es.keygetvalue(kg_set, user_steamid, "edit")

	if text != "!cancel":
		tokens = {}
		tokens["steamid"] = text
		tokens["name"] = text

		player = playerlib.getPlayer(userid)

		if es.exists("key", kg_admins, text) == 0:
			es.keycreate(kg_admins, text)

			es.keysetvalue(kg_admins, text, "name", es.keygetvalue(kg_admins, steamid, "name"))

			for i in range(0, len(access)):
				es.keysetvalue(kg_admins, text, access[i], es.keygetvalue(kg_admins, steamid, access[i]))

			es.keydelete(kg_admins, steamid)

			es.keygroupsave(kg_admins, "soccer_mod")

			es.keysetvalue(kg_set, user_steamid, "edit", text)
			steamid = text

			es.tell(userid, "#green", messages("steamid_changed", tokens, player.get("lang")))
		else:
			es.tell(userid, "#green", messages("add_admin_exist", tokens, player.get("lang")))

	es.keydelete(kg_set, user_steamid)
	es.keycreate(kg_set, user_steamid)
	es.keysetvalue(kg_set, user_steamid, "edit", steamid)

	create_popup_edit(userid, steamid)

def edit_access(userid, choice, popupid):
	tokens = {}
	player = playerlib.getPlayer(userid)

	steamid = es.keygetvalue(kg_set, es.getplayersteamid(userid), "edit")

	if access[choice - 1] == "manager":
		number = 0
		for admin in keyvalues.getKeyGroup(kg_admins):
			value = str(admin)
			value = value.encode("utf-8")
			if value != steamid:
				if int(admin["manager"]) == 1:
					number += 1
	else:
		number = 1

	if choice > 0 and choice < 9:
		try:
			if int(es.keygetvalue(kg_admins, steamid, access[choice - 1])) == 1:
				if number > 0:
					es.keysetvalue(kg_admins, steamid, access[choice - 1], 0)
				else:
					es.tell(userid, "#green", messages("1_admin", tokens, player.get("lang")))
			else:
				es.keysetvalue(kg_admins, steamid, access[choice - 1], 1)
		except ValueError:
			es.keysetvalue(kg_admins, steamid, access[choice - 1], 1)

	es.keygroupsave(kg_admins, "soccer_mod")

	create_popup_edit_access(userid, steamid)

def set_key(userid, type, lang):
	tokens = {}
	player = playerlib.getPlayer(userid)

	if es.exists("key", kg_set, player.steamid) == 0:
		es.keycreate(kg_set, player.steamid)

	es.keysetvalue(kg_set, player.steamid, "setting_type", type)

	es.tell(userid, "#green", messages(lang, tokens, player.get("lang")))

def clear_key(userid, steamid):
	es.keydelete(kg_set, steamid)

	popuplib.send(popup_name, userid)

# ******************** Unload ********************
def unload():
	if es.exists("keygroup", "soccer_mod_admins") == 1:
		es.keygroupdelete("soccer_mod_admins")

	es.addons.unregisterSayFilter(filter)

	popuplib.delete(popup_name)

	es.unload("soccer_mod_2010/admin/manager/admins/create")